@@ -30,12 +30,15 @@
 #include <glib/gi18n.h>
 #include <glib-object.h>
 #include <gst/gst.h>
+#include <gst/tag/tag.h>
 #include <profiles/gnome-media-profiles.h>
+#include "sound-juicer.h"
 #include "sj-extractor.h"
 #include "sj-structures.h"
 #include "sj-error.h"
 #include "sj-util.h"
 
+
 /* Properties */
 enum {
   PROP_0,
@@ -56,7 +59,6 @@ static guint signals[LAST_SIGNAL] = { 0 };
 #define DEFAULT_AUDIO_PROFILE_NAME "cdlossy"
 
 /* Element names */
-#define CD_SRC "cdparanoiasrc"
 #define FILE_SINK "gnomevfssink"
 
 struct SjExtractorPrivate {
@@ -65,7 +67,7 @@ struct SjExtractorPrivate {
   /** If the pipeline needs to be re-created */
   gboolean rebuild_pipeline;
   /* The gstreamer pipeline elements */
-  GstElement *pipeline, *cdparanoia, *queue, *thread, *encoder, *filesink;
+  GstElement *pipeline, *cdsrc, *queue, *thread, *encoder, *filesink;
   GstFormat track_format;
   char *device_path;
   int paranoia_mode;
@@ -148,6 +150,7 @@ static void sj_extractor_set_property (GObject *object, guint property_id,
   case PROP_PROFILE:
     priv->profile = g_value_get_object (value);
     priv->rebuild_pipeline = TRUE;
+    g_object_notify (object, "profile");
     break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -209,7 +212,7 @@ static void eos_cb (GstBus *bus, GstMessage *message, gpointer user_data)
 
 /* Stolen from gst-plugins-good/ext/gconf/gconf.c */
 static GstPad *
-gst_bin_find_unconnected_pad (GstBin * bin, GstPadDirection direction)
+my_gst_bin_find_unconnected_pad (GstBin * bin, GstPadDirection direction)
 {
   GstPad *pad = NULL;
   GList *elements = NULL;
@@ -249,7 +252,7 @@ gst_bin_find_unconnected_pad (GstBin * bin, GstPadDirection direction)
 
 /* Stolen from gst-plugins-good/ext/gconf/gconf.c */
 static GstElement *
-gst_gconf_render_bin_from_description (const gchar * description)
+my_gst_gconf_render_bin_from_description (const gchar * description)
 {
   GstElement *bin = NULL;
   GstPad *pad = NULL;
@@ -268,10 +271,10 @@ gst_gconf_render_bin_from_description (const gchar * description)
   }
 
   /* find pads and ghost them if necessary */
-  if ((pad = gst_bin_find_unconnected_pad (GST_BIN (bin), GST_PAD_SRC))) {
+  if ((pad = my_gst_bin_find_unconnected_pad (GST_BIN (bin), GST_PAD_SRC))) {
     gst_element_add_pad (bin, gst_ghost_pad_new ("src", pad));
   }
-  if ((pad = gst_bin_find_unconnected_pad (GST_BIN (bin), GST_PAD_SINK))) {
+  if ((pad = my_gst_bin_find_unconnected_pad (GST_BIN (bin), GST_PAD_SINK))) {
     gst_element_add_pad (bin, gst_ghost_pad_new ("sink", pad));
   }
   return bin;
@@ -288,7 +291,7 @@ static GstElement* build_encoder (SjExtractor *extractor)
   g_return_val_if_fail (priv->profile != NULL, NULL);
  
   pipeline = g_strdup_printf ("audioconvert ! %s", gm_audio_profile_get_pipeline (priv->profile));
-  element = gst_gconf_render_bin_from_description (pipeline);
+  element = my_gst_gconf_render_bin_from_description (pipeline);
   g_free(pipeline);
   return element;
 }
@@ -336,16 +339,16 @@ static void build_pipeline (SjExtractor *extractor)
   g_signal_connect (G_OBJECT (bus), "message::error", G_CALLBACK (error_cb), extractor);
 
   /* Read from CD */
-  priv->cdparanoia = gst_element_factory_make (CD_SRC, "cd_src");
-  if (priv->cdparanoia == NULL) {
+  priv->cdsrc = gst_element_factory_make (CD_SRC, "cd_src");
+  if (priv->cdsrc == NULL) {
     g_set_error (&priv->construct_error,
                  SJ_ERROR, SJ_ERROR_INTERNAL_ERROR,
-                 _("Could not create GStreamer cdparanoia reader"));
+                 _("Could not create GStreamer CD reader"));
     return;
   }
 
-  g_object_set (G_OBJECT (priv->cdparanoia), "device", priv->device_path, NULL);
-  g_object_set (G_OBJECT (priv->cdparanoia), "paranoia-mode", priv->paranoia_mode, NULL);
+  g_object_set (G_OBJECT (priv->cdsrc), "device", priv->device_path, NULL);
+  g_object_set (G_OBJECT (priv->cdsrc), "paranoia-mode", priv->paranoia_mode, NULL);
 
   /* Get the track format for seeking later */
   priv->track_format = gst_format_get_by_nick ("track");
@@ -377,10 +380,10 @@ static void build_pipeline (SjExtractor *extractor)
   g_signal_connect (G_OBJECT (priv->filesink), "allow-overwrite", G_CALLBACK (just_say_yes), extractor);
 
   /* Add the elements to the pipeline */
-  gst_bin_add_many (GST_BIN (priv->pipeline), priv->cdparanoia, priv->queue, priv->encoder, priv->filesink, NULL);
+  gst_bin_add_many (GST_BIN (priv->pipeline), priv->cdsrc, priv->queue, priv->encoder, priv->filesink, NULL);
 
   /* Link it all together */
-  if (!gst_element_link_many (priv->cdparanoia, priv->queue, priv->encoder, priv->filesink, NULL)) {
+  if (!gst_element_link_many (priv->cdsrc, priv->queue, priv->encoder, priv->filesink, NULL)) {
     /* TODO: need to produce a GError here */
     g_warning ("Cannot link pipeline, very bad!");
     g_object_unref (priv->pipeline);
@@ -404,7 +407,7 @@ static gboolean tick_timeout_cb(SjExtractor *extractor)
     return FALSE;
   }
 
-  if (!gst_element_query_position (extractor->priv->cdparanoia, &format, &nanos)) {
+  if (!gst_element_query_position (extractor->priv->cdsrc, &format, &nanos)) {
     g_warning (_("Could not get current track position"));
     return TRUE;
   }
@@ -446,8 +449,8 @@ void sj_extractor_set_device (SjExtractor *extractor, const char* device)
   g_free (extractor->priv->device_path);
   extractor->priv->device_path = g_strdup (device);
 
-  if (extractor->priv->cdparanoia != NULL)
-    g_object_set (G_OBJECT (extractor->priv->cdparanoia), "device", device, NULL);
+  if (extractor->priv->cdsrc != NULL)
+    g_object_set (G_OBJECT (extractor->priv->cdsrc), "device", device, NULL);
 }
 
 void sj_extractor_set_paranoia (SjExtractor *extractor, const int paranoia_mode)
@@ -455,8 +458,8 @@ void sj_extractor_set_paranoia (SjExtractor *extractor, const int paranoia_mode)
   g_return_if_fail (SJ_IS_EXTRACTOR (extractor));
 
   extractor->priv->paranoia_mode = paranoia_mode;
-  if (extractor->priv->cdparanoia != NULL)
-    g_object_set (G_OBJECT (extractor->priv->cdparanoia), "paranoia-mode", paranoia_mode, NULL);
+  if (extractor->priv->cdsrc != NULL)
+    g_object_set (G_OBJECT (extractor->priv->cdsrc), "paranoia-mode", paranoia_mode, NULL);
 }
 
 void sj_extractor_extract_track (SjExtractor *extractor, const TrackDetails *track, const char* url, GError **error)
@@ -507,38 +510,40 @@ void sj_extractor_extract_track (SjExtractor *extractor, const TrackDetails *tra
                                GST_TAG_ENCODER, _("Sound Juicer"),
                                GST_TAG_ENCODER_VERSION, VERSION,
                                NULL);
-#if 0
+
+#ifdef GST_TAG_MUSICBRAINZ_ALBUMID
       if (track->album->album_id != NULL && strcmp (track->album->album_id, "") != 0) {
-        gst_tag_setter_add_tags (GST_TAG_SETTER (elt->data),
+        gst_tag_setter_add_tags (tagger,
                             GST_TAG_MERGE_APPEND,
                             GST_TAG_MUSICBRAINZ_ALBUMID, track->album->album_id,
                             NULL);
       }
       if (track->album->artist_id != NULL && strcmp (track->album->artist_id, "") != 0) {
-        gst_tag_setter_add_tags (GST_TAG_SETTER (elt->data),
+        gst_tag_setter_add_tags (tagger,
                             GST_TAG_MERGE_APPEND,
                             GST_TAG_MUSICBRAINZ_ALBUMARTISTID, track->album->artist_id,
                             NULL);
       }
       if (track->artist_id != NULL && strcmp (track->artist_id, "") != 0) {
-        gst_tag_setter_add_tags (GST_TAG_SETTER (elt->data),
+        gst_tag_setter_add_tags (tagger,
                             GST_TAG_MERGE_APPEND,
                             GST_TAG_MUSICBRAINZ_ARTISTID, track->artist_id,
                             NULL);
       }
       if (track->track_id != NULL && strcmp (track->track_id, "") != 0) {
-        gst_tag_setter_add_tags (GST_TAG_SETTER (elt->data),
+        gst_tag_setter_add_tags (tagger,
                             GST_TAG_MERGE_APPEND,
                             GST_TAG_MUSICBRAINZ_TRACKID, track->track_id,
                             NULL);
       }
       if (track->artist_sortname != NULL && strcmp (track->artist_sortname, "") != 0) {
-        gst_tag_setter_add_tags (GST_TAG_SETTER (elt->data),
+        gst_tag_setter_add_tags (tagger,
                             GST_TAG_MERGE_APPEND,
                             GST_TAG_MUSICBRAINZ_SORTNAME, track->artist_sortname,
                             NULL);
       }
 #endif
+
       if (track->album->genre != NULL && strcmp (track->album->genre, "") != 0) {
         gst_tag_setter_add_tags (tagger,
                                  GST_TAG_MERGE_APPEND,
@@ -568,13 +573,13 @@ void sj_extractor_extract_track (SjExtractor *extractor, const TrackDetails *tra
   gst_iterator_free (iter);
 
   /* Seek to the right track */
-  g_object_set (G_OBJECT (priv->cdparanoia), "track", track->number, NULL);
+  g_object_set (G_OBJECT (priv->cdsrc), "track", track->number, NULL);
   
   /* Let's get ready to rumble! */
   gst_element_set_state (priv->pipeline, GST_STATE_PAUSED);
   gst_element_get_state (priv->pipeline, NULL, NULL, GST_CLOCK_TIME_NONE);
 
-  if (!gst_element_query_position (priv->cdparanoia, &format, &nanos)) {
+  if (!gst_element_query_position (priv->cdsrc, &format, &nanos)) {
     g_warning (_("Could not get track start position"));
     return;
   }
